@@ -3,7 +3,7 @@
 
 #
 # Dell EMC OpenManage Ansible Modules
-# Version 3.0.0
+# Version 3.6.0
 # Copyright (C) 2020-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -140,12 +140,12 @@ additional_info:
         "@Message.ExtendedInfo": [
             {
                 "RelatedProperties": [],
-                "Message":  "Fabric update is successful. The OverrideLLDPConfiguration attribute is not provided in the
-                 payload, so it preserves the previous value.",
+                "Message":  "Fabric update is successful. The OverrideLLDPConfiguration attribute is not provided in the
+                 payload, so it preserves the previous value.",
                 "MessageArgs": [],
                 "Severity": "Informational",
-                "Resolution": "Please update the Fabric with the OverrideLLDPConfiguration as Disabled or Enabled if
-                 necessary."
+                "Resolution": "Please update the Fabric with the OverrideLLDPConfiguration as Disabled or Enabled if
+                 necessary."
             }
         ]
     }
@@ -218,7 +218,7 @@ def get_service_tag_with_fqdn(rest_obj, module):
     device_details = rest_obj.get_all_items_with_pagination(DEVICE_URI)
     for each_device in device_details["value"]:
         for item in each_device["DeviceManagement"]:
-            if item.get("DnsName") == hostname:
+            if item.get("DnsName") == hostname or item.get('NetworkAddress') == hostname:
                 return each_device["DeviceServiceTag"]
     return service_tag
 
@@ -313,13 +313,19 @@ def idempotency_check_for_state_present(fabric_id, current_payload, expected_pay
     :return: None
     """
     if fabric_id:
-        payload_diff = compare_payloads(expected_payload, current_payload)
+        exp_dict = expected_payload.copy()
+        cur_dict = current_payload.copy()
+        for d in (exp_dict, cur_dict):
+            fab_dz_lst = d.pop("FabricDesignMapping", [])
+            for fab in fab_dz_lst:
+                d[fab.get('DesignNode')] = fab.get('PhysicalNode')
+        payload_diff = compare_payloads(exp_dict, cur_dict)
         if module.check_mode:
             if payload_diff:
                 module.exit_json(msg=CHECK_MODE_CHANGE_FOUND_MSG, changed=True)
             else:
                 module.exit_json(msg=CHECK_MODE_CHANGE_NOT_FOUND_MSG, changed=False)
-        elif not module.check_mode and not payload_diff:
+        elif not payload_diff:
             module.exit_json(msg=IDEMPOTENCY_MSG, changed=False)
     else:
         if module.check_mode:
@@ -459,10 +465,8 @@ def create_modify_payload(module_params, fabric_id, msm_version):
         "Name": backup_params["name"],
         "Description": backup_params.get("description"),
         "OverrideLLDPConfiguration": backup_params.get("override_LLDP_configuration"),
-        "FabricDesignMapping": [
-        ],
-        "FabricDesign": {
-        }
+        "FabricDesignMapping": [],
+        "FabricDesign": {}
     }
     if backup_params.get("primary_switch_service_tag"):
         _payload["FabricDesignMapping"].append({
