@@ -85,7 +85,11 @@ def main():
     module = AnsibleModule(argument_spec)
     check_sdk(module)
     if module.params['fetch_nested'] or module.params['nested_attributes']:
-        module.deprecate("The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter", version='2.0')
+        module.deprecate(
+            "The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter",
+            version='2.0.0',
+            collection_name='ovirt.ovirt'
+        )
 
     try:
         auth = module.params.pop('auth')
